@@ -28,7 +28,7 @@
 #include "adios2/core/CoreTypes.h"
 #include "adios2/core/Group.h"
 #include "adios2/core/Variable.h"
-#include "adios2/core/VariableCompound.h"
+#include "adios2/core/VariableStruct.h"
 
 namespace adios2
 {
@@ -182,6 +182,13 @@ public:
                    const Dims &start = Dims(), const Dims &count = Dims(),
                    const bool constantDims = false);
 
+    VariableStruct &DefineStructVariable(const std::string &name,
+                                         StructDefinition &def,
+                                         const Dims &shape = Dims(),
+                                         const Dims &start = Dims(),
+                                         const Dims &count = Dims(),
+                                         const bool constantDims = false);
+
     /**
      * @brief Define array attribute
      * @param name must be unique for the IO object
@@ -273,6 +280,14 @@ public:
     template <class T>
     Variable<T> *InquireVariable(const std::string &name) noexcept;
 
+    VariableStruct *InquireStructVariable(const std::string &name) noexcept;
+
+    VariableStruct *
+    InquireStructVariable(const std::string &name, const StructDefinition &def,
+                          const bool allowReorganize = false) noexcept;
+
+    StructDefinition &DefineStruct(const std::string &name, const size_t size);
+
     /**
      * @brief Returns the type of an existing variable as an string
      * @param name input variable name
